@@ -1,6 +1,6 @@
 /* utimecmp.h -- compare file timestamps
 
-   Copyright (C) 2004, 2009-2017 Free Software Foundation, Inc.
+   Copyright (C) 2004, 2009-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,5 +33,7 @@ enum
 };
 
 int utimecmp (char const *, struct stat const *, struct stat const *, int);
+int utimecmpat (int, char const *, struct stat const *, struct stat const *,
+                int);
 
 #endif
