@@ -1,5 +1,5 @@
 /* nohup -- run a command immune to hangups, with output to a non-tty
-   Copyright (C) 2003-2017 Free Software Foundation, Inc.
+   Copyright (C) 2003-2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Written by Jim Meyering  */
 
@@ -34,6 +34,11 @@
 
 #define AUTHORS proper_name ("Jim Meyering")
 
+static struct option const long_options[] =
+{
+  {NULL, 0, NULL, 0}
+};
+
 /* Exit statuses.  */
 enum
   {
@@ -101,7 +106,7 @@ main (int argc, char **argv)
 
   parse_long_options (argc, argv, PROGRAM_NAME, PACKAGE_NAME, Version,
                       usage, AUTHORS, (char const *) NULL);
-  if (getopt_long (argc, argv, "+", NULL, NULL) != -1)
+  if (getopt_long (argc, argv, "+", long_options, NULL) != -1)
     usage (exit_internal_failure);
 
   if (argc <= optind)
